<?php
/**
Plugin Name: GETBATS O2O
description: GETBATS O2O Plugin
Version: 1.0
Author: GETBATS
Author URI: https://www.getbats.com
*/ 
defined('ABSPATH' ) or die( 'No script kiddies please!' );

add_action('admin_menu', 'gbo2o_register_cashback_plugin');

function gbo2o_register_cashback_plugin() {
  add_menu_page(
    'GETBATS O2O',
    'GETBATS O2O',
    'manage_options',
    'gbo2o_cashback',
    'gbo2o_add_callback',
    'dashicons-star-empty',
    200
  );
}

function gbo2o_add_callback() {
  ?>
  <style>
    .gbo_cashback_plugin .title {
     padding: 10px 0px;
    }
    .gbo_cashback_plugin form {
      margin: 20px 0px;
    }

    .gbo_cashback_plugin form .label {
      font-weight: 500;
      padding: 10px 0px;
      font-size: 14px;
    }
    .gbo_cashback_plugin form .input {
      padding: 10px 0px;
    }
    .gbo_cashback_plugin form .input .radio {
      margin-right: 10px;
      display: inline-block;
    }

    .gbo_cashback_plugin form .button {
      width: 100px;
      margin: 10px 0px;
    }
  </style>
  <div class="gbo_cashback_plugin">
    <nav class="navbar navbar-light bg-light">
      <h1 class="navbar-brand mr-auto" href="#">Cashback Plugin</h1>
    </nav>
    <div class="wrap">
      <div id="icon-tools" class="icon32"></div>
        <form action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>" method="POST">
          <h1 class="title">Your Access Credentials</h1>
          <div class="label">Merchant Key</div>
          <div class="input">
            <input type="text" name="merchant_key" value="<?php echo esc_attr(get_option('cashback_merchant_key')); ?>" placeholder="Merchant Key">
          </div>
          <div class="label">Cashback %</div>
          <div class="input">
            <input type="text" name="cashback_percentage" value="<?php echo esc_attr(get_option('cashback_percentage')); ?>" placeholder="Cashback Percentage">
          </div>
          <input type="hidden" name="action" value="gbo2o_cashback_save_config">
          <input type="submit" name="submit" id="submit1" class="update-button button button-primary" value="Save"  />
        </form>
      </div>
      <h4><?php echo (isset($_GET['status']) && $_GET['status'] === '1') ? 'SUCCESS' : '' ?></h4>
    </div>
<?php
}

add_action('admin_post_gbo2o_cashback_save_config', 'gbo2o_cashback_save_config' );
function gbo2o_cashback_save_config() {
  if (isset($_POST['merchant_key'])) {
    $merchant_key = sanitize_text_field( $_POST['merchant_key'] );
	  $cashback_percentage = sanitize_text_field( $_POST['cashback_percentage'] );
    $config_exists = get_option('cashback_merchant_key');
    if (!empty($_POST['merchant_key']) && !empty($config_exists)) {
      update_option('cashback_merchant_key', $merchant_key);
	    update_option('cashback_percentage', $cashback_percentage);
    } else {
      add_option('cashback_merchant_key', $merchant_key);
	    add_option('cashback_percentage', $cashback_percentage);
    }
  }
  wp_redirect($_SERVER['HTTP_REFERER']);
}

add_action('init','gbo2o_getbats_save_cookie');
function gbo2o_getbats_save_cookie() {
  if(isset($_GET['id_trip']) && !empty($_GET['id_trip'])) {
    setcookie('id_trip', sanitize_text_field($_GET['id_trip']), time() + (10 * 365 * 24 * 60 * 60));
  }
}

// woocommerce_checkout_update_order_meta
add_filter('woocommerce_checkout_update_order_meta' , 'gbo2o_custom_checkout_update_meta', 10, 2);
function gbo2o_custom_checkout_update_meta($order_id, $data) {
  $trip_id = null;
  if(isset($_GET['id_trip']) && !empty($_GET['id_trip'])) {
    $trip_id = sanitize_text_field($_GET['id_trip']);
  } else if (isset($_COOKIE['id_trip']) && !empty($_COOKIE['id_trip'])) {
    $trip_id = sanitize_text_field($_COOKIE['id_trip']);
  }
  if (isset($trip_id)) {
    $billing_trip_id = get_post_meta($order_id, 'billing_trip_id', true);
    if (!$billing_trip_id) {
      update_post_meta($order_id, 'billing_trip_id', $trip_id);
    } else {
      add_post_meta($order_id, 'billing_trip_id', $trip_id);
    }
  }
}


add_action('woocommerce_order_status_completed', 'gbo2o_payment_complete', 10, 1);
function gbo2o_payment_complete($order_id) {  
  $merchantkey = esc_attr(get_option('cashback_merchant_key'));
  $cashback_percentage_value = esc_attr(get_option('cashback_percentage'));
  $billing_trip_id = get_post_meta($order_id,'billing_trip_id', true);

  if ($merchantkey && $billing_trip_id) {
    $order = wc_get_order( $order_id );
    $completed_date_time = $order->get_date_completed()->format ('Y-m-d H:i:s');;
    $total = number_format( (float) $order->get_total() - $order->get_total_tax() - $order->get_total_shipping(), wc_get_price_decimals(), '.', '' ); //$order->get_total();
    $cashback = (($cashback_percentage_value/100) * $total);  //"0";
    
    foreach ( $order->get_items() as $item_id => $item ) {
      $product_id = $item->get_product_id();
      $variation_id = $item->get_variation_id();
      $product = $item->get_product();
      $name = $item->get_name();
      $quantity = $item->get_quantity();
      $subtotal = $item->get_subtotal();
      $itemtotal = $item->get_total();
      $tax = $item->get_subtotal_tax();
      $taxclass = $item->get_tax_class();
      $taxstat = $item->get_tax_status();
      $allmeta = $item->get_meta_data();
      $type = $item->get_type();
    }
  
   
    $url = 'https://batsoffice.getbats.com/admin/a_o2o_platform_postback.php';
    $encode = sha1($merchantkey.$order_id.$cashback.$completed_date_time.$total);
    // post to the request somehow
    $response = wp_remote_post(
      $url,
      array(
        'method' => 'POST',
        'timeout' => 45,
        'redirection' => 5,
        'httpversion' => '1.0',
        'blocking' => true,
        'headers' => array(),
        'body' => array( 
          'trip_id' => $billing_trip_id, 
          'transaction_id' => $order_id, 
          'price' => $total, 
          'datetime' => $completed_date_time, 
          'cashback' => $cashback,
          'encode' => $encode
          ),
        'cookies' => array()
      )
    );
  
    if (is_wp_error($response)) {
      $error_message = $response->get_error_message();
      echo "Something went wrong: $error_message";
    } else {
      echo 'Response:<pre>';
      print_r( $response );
      echo '</pre>';
    }
  }
} //end of gbo2o_payment_complete
?>